@@ -2,7 +2,7 @@
 // GB_transpose: C=A' or C=op(A'), with typecasting
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2023, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2025, All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
@@ -36,10 +36,10 @@
 
 #define GB_FREE_WORKSPACE               \
 {                                       \
-    GB_FREE (&iwork, iwork_size) ;      \
-    GB_FREE (&jwork, jwork_size) ;      \
-    GB_FREE (&Swork, Swork_size) ;      \
-    GB_WERK_POP (Count, int64_t) ;      \
+    GB_FREE_MEMORY (&iwork, iwork_size) ;      \
+    GB_FREE_MEMORY (&jwork, jwork_size) ;      \
+    GB_FREE_MEMORY (&Swork, Swork_size) ;      \
+    GB_WERK_POP (Count, uint64_t) ;     \
 }
 
 #define GB_FREE_ALL                     \
@@ -83,24 +83,19 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
     ASSERT (C != NULL) ;
     ASSERT (A != NULL) ;
     bool in_place = (A == C) ;
-    GB_WERK_DECLARE (Count, int64_t) ;
-    int64_t *iwork = NULL ; size_t iwork_size = 0 ;
-    int64_t *jwork = NULL ; size_t jwork_size = 0 ;
+    GB_WERK_DECLARE (Count, uint64_t) ;
+    void *iwork = NULL ; size_t iwork_size = 0 ;
+    void *jwork = NULL ; size_t jwork_size = 0 ;
     GB_void *Swork = NULL ; size_t Swork_size = 0 ;
     struct GB_Matrix_opaque T_header ;
     GrB_Matrix T = NULL ;
-    GB_CLEAR_STATIC_HEADER (T, &T_header) ;
+    GB_CLEAR_MATRIX_HEADER (T, &T_header) ;
 
     ASSERT_MATRIX_OK (A, "A input for GB_transpose", GB0) ;
     ASSERT_TYPE_OK_OR_NULL (ctype, "ctype for GB_transpose", GB0) ;
     ASSERT_OP_OK_OR_NULL (op_in, "unop/binop for GB_transpose", GB0) ;
     ASSERT_SCALAR_OK_OR_NULL (scalar, "scalar for GB_transpose", GB0) ;
 
-    if (in_place)
-    { 
-        GBURBLE ("(in-place transpose) ") ;
-    }
-
     // get the current sparsity control of A
     float A_hyper_switch = A->hyper_switch ;
     float A_bitmap_switch = A->bitmap_switch ;
@@ -129,6 +124,15 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
     int64_t anz_held = GB_nnz_held (A) ;
     int64_t anvec = A->nvec ;
     int64_t anvals = A->nvals ;
+    bool Ap_is_32 = A->p_is_32 ;
+    bool Aj_is_32 = A->j_is_32 ;
+    bool Ai_is_32 = A->i_is_32 ;
+
+    bool Cp_is_32, Cj_is_32, Ci_is_32 ;
+
+    size_t apsize = (Ap_is_32) ? sizeof (uint32_t) : sizeof (uint64_t) ;
+    size_t ajsize = (Aj_is_32) ? sizeof (uint32_t) : sizeof (uint64_t) ;
+    size_t aisize = (Ai_is_32) ? sizeof (uint32_t) : sizeof (uint64_t) ;
 
     //--------------------------------------------------------------------------
     // determine the max number of threads to use
@@ -247,11 +251,15 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         // A is empty
         //----------------------------------------------------------------------
 
+        // T is created using the requested integers of C.
+        GB_determine_pji_is_32 (&Cp_is_32, &Cj_is_32, &Ci_is_32,
+            GxB_HYPERSPARSE, 0, avdim, avlen, Werk) ;
+
         // create a new empty matrix T, with the new type and dimensions.
-        // set T->iso = false   OK
         GB_OK (GB_new_bix (&T, // hyper, existing header
-            ctype, avdim, avlen, GB_Ap_calloc, C_is_csc, GxB_HYPERSPARSE,
-            true, A_hyper_switch, 1, 1, true, false)) ;
+            ctype, avdim, avlen, GB_ph_calloc, C_is_csc, GxB_HYPERSPARSE,
+            true, A_hyper_switch, 1, 1, true, false,
+            Cp_is_32, Cj_is_32, Ci_is_32)) ;
 
     }
     else if (A_is_bitmap || GB_IS_FULL (A))
@@ -272,23 +280,28 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             && op == NULL                   // no operator to apply,
             && atype == ctype ;             // and no typecasting
 
+        // full/bitmap matrices do not have integers
+        Cp_is_32 = false ;
+        Cj_is_32 = false ;
+        Ci_is_32 = false ;
+
         // allocate T
         if (T_cheap)
         { 
             // just initialize the static header of T, not T->b or T->x
             GBURBLE ("(cheap transpose) ") ;
             info = GB_new (&T, // bitmap or full, existing header
-                ctype, avdim, avlen, GB_Ap_null, C_is_csc,
-                T_sparsity, A_hyper_switch, 1) ;
+                ctype, avdim, avlen, GB_ph_null, C_is_csc,
+                T_sparsity, A_hyper_switch, 1, Cp_is_32, Cj_is_32, Ci_is_32) ;
             ASSERT (info == GrB_SUCCESS) ;
         }
         else
         { 
             // allocate all of T, including T->b and T->x
-            // set T->iso = C_iso   OK
             GB_OK (GB_new_bix (&T, // bitmap or full, existing header
-                ctype, avdim, avlen, GB_Ap_null, C_is_csc, T_sparsity, true,
-                A_hyper_switch, 1, anz_held, true, C_iso)) ;
+                ctype, avdim, avlen, GB_ph_null, C_is_csc, T_sparsity, true,
+                A_hyper_switch, 1, anz_held, true, C_iso,
+                Cp_is_32, Cj_is_32, Ci_is_32)) ;
         }
 
         T->magic = GB_MAGIC ;
@@ -348,7 +361,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         //----------------------------------------------------------------------
 
         // transpose a vector (avlen-by-1) into a "row" matrix (1-by-avlen).
-        // A must be sorted first.
+        // A must be sorted first. 
 
         GBURBLE ("(sparse vector transpose (a)) ") ;
         ASSERT_MATRIX_OK (A, "the vector A must already be sorted", GB0) ;
@@ -358,23 +371,29 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         // allocate T
         //----------------------------------------------------------------------
 
-        // Initialized the header of T, with no content, and initialize the
-        // type and dimension of T.  T is hypersparse.
+        // Initialize the header of T, with no content, and initialize the
+        // type and dimension of T.  T is hypersparse.  The integers for T->p
+        // are the same as A->p, but the integers for T->i and T->h are swapped
+        // with A.
+
+        Cp_is_32 = Ap_is_32 ;
+        Cj_is_32 = Ai_is_32 ;   // create T->h with the integers of A->i
+        Ci_is_32 = Aj_is_32 ;   // create T->i with the integers of A->h
 
         info = GB_new (&T, // hyper; existing header
-            ctype, 1, avlen, GB_Ap_null, C_is_csc,
-            GxB_HYPERSPARSE, A_hyper_switch, 0) ;
+            ctype, 1, avlen, GB_ph_null, C_is_csc,
+            GxB_HYPERSPARSE, A_hyper_switch, 0, Cp_is_32, Cj_is_32, Ci_is_32) ;
         ASSERT (info == GrB_SUCCESS) ;
 
         // allocate T->p, T->i, and optionally T->x, but not T->h
         int64_t tplen = GB_IMAX (1, anz) ;
-        T->p = GB_MALLOC (tplen+1, int64_t, &(T->p_size)) ;
-        T->i = GB_MALLOC (anz    , int64_t, &(T->i_size)) ;
+        T->p = GB_MALLOC_MEMORY (tplen+1, apsize, &(T->p_size)) ;
+        T->i = GB_MALLOC_MEMORY (anz    , ajsize, &(T->i_size)) ;
         bool allocate_Tx = (op != NULL || C_iso) || (ctype != atype) ;
         if (allocate_Tx)
         { 
             // allocate new space for the new typecasted numerical values of T
-            T->x = GB_XALLOC (false, C_iso, anz, csize, &(T->x_size)) ; // x:OK
+            T->x = GB_XALLOC_MEMORY (false, C_iso, anz, csize, &(T->x_size)) ;
         }
         if (T->p == NULL || T->i == NULL || (allocate_Tx && T->x == NULL))
         { 
@@ -438,7 +457,11 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         // T->p = 0:anz and T->i = zeros (1,anz), newly allocated
         T->plen = tplen ;
         T->nvec = anz ;
-        T->nvec_nonempty = anz ;
+//      T->nvec_nonempty = anz ;
+        GB_nvec_nonempty_set (T, anz) ;
+
+        GB_Ap_DECLARE (Tp, ) ; GB_Ap_PTR (Tp, T) ;
+        GB_Ai_DECLARE (Ti, ) ; GB_Ai_PTR (Ti, T) ;
 
         // fill the vector pointers T->p
         int nthreads = GB_nthreads (anz, chunk, nthreads_max) ;
@@ -446,10 +469,13 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         #pragma omp parallel for num_threads(nthreads) schedule(static)
         for (k = 0 ; k < anz ; k++)
         { 
-            T->i [k] = 0 ;
-            T->p [k] = k ;
+            // Ti [k] = 0 ;
+            GB_ISET (Ti, k, 0) ;
+            // Tp [k] = k ;
+            GB_ISET (Tp, k, k) ;
         }
-        T->p [anz] = anz ;
+        // Tp [anz] = anz ;
+        GB_ISET (Tp, anz, anz) ;
 
         T->iso = C_iso ;
         T->nvals = anz ;
@@ -464,7 +490,8 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         //----------------------------------------------------------------------
 
         // transpose a "row" matrix (1-by-avdim) into a vector (avdim-by-1).
-        // if A->vlen is 1, all vectors of A are implicitly sorted
+        // if A->vlen is 1, all vectors of A are implicitly sorted.
+
         GBURBLE ("(sparse vector transpose (b)) ") ;
         ASSERT_MATRIX_OK (A, "1-by-n input A already sorted", GB0) ;
 
@@ -480,7 +507,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             ntasks = 8 * nth ;
             ntasks = GB_IMIN (ntasks, avdim) ;
             ntasks = GB_IMAX (ntasks, 1) ;
-            GB_WERK_PUSH (Count, ntasks+1, int64_t) ;
+            GB_WERK_PUSH (Count, ntasks+1, uint64_t) ;
             if (Count == NULL)
             { 
                 // out of memory
@@ -489,27 +516,39 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             }
         }
 
+        //----------------------------------------------------------------------
+        // allocate T
+        //----------------------------------------------------------------------
+
+        // Initialize the header of T, with no content, and initialize the type
+        // and dimension of T.  T is sparse.  The integers for T->p are the
+        // same as A->p, but the integers for T->i and T->h are swapped with A.
+
+        Cp_is_32 = Ap_is_32 ;
+        Cj_is_32 = Ai_is_32 ;   // create T->h with the integers of A->i
+        Ci_is_32 = Aj_is_32 ;   // create T->i with the integers of A->h
+
         // Allocate the header of T, with no content
         // and initialize the type and dimension of T.
         info = GB_new (&T, // sparse; existing header
-            ctype, avdim, 1, GB_Ap_null, C_is_csc,
-            GxB_SPARSE, A_hyper_switch, 0) ;
+            ctype, avdim, 1, GB_ph_null, C_is_csc,
+            GxB_SPARSE, A_hyper_switch, 0, Cp_is_32, Cj_is_32, Ci_is_32) ;
         ASSERT (info == GrB_SUCCESS) ;
 
         T->iso = C_iso ;    // OK
 
         // allocate new space for the values and pattern
-        T->p = GB_CALLOC (2, int64_t, &(T->p_size)) ;
+        T->p = GB_CALLOC_MEMORY (2, apsize, &(T->p_size)) ;
         if (!A_is_hyper)
         { 
             // A is sparse, so new space is needed for T->i
-            T->i = GB_MALLOC (anz, int64_t, &(T->i_size)) ;
+            T->i = GB_MALLOC_MEMORY (anz, ajsize, &(T->i_size)) ;
         }
         bool allocate_Tx = (op != NULL || C_iso) || (ctype != atype) ;
         if (allocate_Tx)
         { 
             // allocate new space for the new typecasted numerical values of T
-            T->x = GB_XALLOC (false, C_iso, anz, csize, &(T->x_size)) ; // x:OK
+            T->x = GB_XALLOC_MEMORY (false, C_iso, anz, csize, &(T->x_size)) ;
         }
 
         if (T->p == NULL || (T->i == NULL && !A_is_hyper) ||
@@ -587,6 +626,9 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             // find the non-empty vectors of A, which become entries in T
             //------------------------------------------------------------------
 
+            GB_Ap_DECLARE (Ap, const) ; GB_Ap_PTR (Ap, A) ;
+            GB_Ai_DECLARE (Ti,      ) ; GB_Ai_PTR (Ti, T) ;
+
             if (nth == 1)
             {
 
@@ -597,9 +639,11 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
                 int64_t k = 0 ;
                 for (int64_t j = 0 ; j < avdim ; j++)
                 {
-                    if (A->p [j] < A->p [j+1])
+                    if (GB_IGET (Ap, j) < GB_IGET (Ap, j+1))
                     { 
-                        T->i [k++] = j ;
+                        // Ti [k++] = j ;
+                        GB_ISET (Ti, k, j) ;
+                        k++ ;
                     }
                 }
                 ASSERT (k == anz) ;
@@ -620,7 +664,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
                     GB_PARTITION (jstart, jend, avdim, tid, ntasks) ;
                     for (int64_t j = jstart ; j < jend ; j++)
                     {
-                        if (A->p [j] < A->p [j+1])
+                        if (GB_IGET (Ap, j) < GB_IGET (Ap, j+1))
                         { 
                             k++ ;
                         }
@@ -628,7 +672,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
                     Count [tid] = k ;
                 }
 
-                GB_cumsum1 (Count, ntasks) ;
+                GB_cumsum1_64 (Count, ntasks) ;
                 ASSERT (Count [ntasks] == anz) ;
 
                 #pragma omp parallel for num_threads(nth) schedule(dynamic,1)
@@ -638,9 +682,11 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
                     GB_PARTITION (jstart, jend, avdim, tid, ntasks) ;
                     for (int64_t j = jstart ; j < jend ; j++)
                     {
-                        if (A->p [j] < A->p [j+1])
+                        if (GB_IGET (Ap, j) < GB_IGET (Ap, j+1))
                         { 
-                            T->i [k++] = j ;
+                            // Ti [k++] = j ;
+                            GB_ISET (Ti, k, j) ;
+                            k++ ;
                         }
                     }
                 }
@@ -650,9 +696,9 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             int64_t k = 0 ;
             for (int64_t j = 0 ; j < avdim ; j++)
             {
-                if (A->p [j] < A->p [j+1])
+                if (GB_IGET (Ap, j) < GB_IGET (Ap, j+1))
                 {
-                    ASSERT (T->i [k] == j) ;
+                    ASSERT (GB_IGET (Ti, k) == j) ;
                     k++ ;
                 }
             }
@@ -667,8 +713,15 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         // T->p = [0 anz]
         ASSERT (T->plen == 1) ;
         ASSERT (T->nvec == 1) ;
-        T->nvec_nonempty = (anz == 0) ? 0 : 1 ;
-        T->p [1] = anz ;
+//      T->nvec_nonempty = (anz == 0) ? 0 : 1 ;
+        GB_nvec_nonempty_set (T, (anz == 0) ? 0 : 1) ;
+
+        GB_Ap_DECLARE (Tp, ) ; GB_Ap_PTR (Tp, T) ;
+        // Tp [0] = 0 ;
+        // Tp [1] = anz ;
+        GB_ISET (Tp, 0, 0) ;
+        GB_ISET (Tp, 1, anz) ;
+
         T->nvals = anz ;
         T->magic = GB_MAGIC ;
         ASSERT (!GB_JUMBLED (T)) ;
@@ -711,7 +764,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             //------------------------------------------------------------------
 
             // allocate iwork of size anz
-            iwork = GB_MALLOC (anz, int64_t, &iwork_size) ;
+            iwork = GB_MALLOC_MEMORY (anz, ajsize, &iwork_size) ;
             if (iwork == NULL)
             { 
                 // out of memory
@@ -721,26 +774,30 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
 
             // Construct the "row" indices of C, which are "column" indices of
             // A.  This array becomes the permanent T->i on output.
-
-            GB_OK (GB_extract_vector_list (iwork, A, Werk)) ;
+            GB_OK (GB_extract_vector_list (iwork, Aj_is_32, A, Werk)) ;
 
             //------------------------------------------------------------------
             // allocate the output matrix and additional space (jwork and Swork)
             //------------------------------------------------------------------
 
+            // T is created using the requested integers of C.
+            GB_determine_pji_is_32 (&Cp_is_32, &Cj_is_32, &Ci_is_32,
+                GxB_HYPERSPARSE, anz, avdim, avlen, Werk) ;
+
             // initialize the header of T, with no content,
             // and initialize the type and dimension of T.
 
             info = GB_new (&T, // hyper, existing header
-                ctype, avdim, avlen, GB_Ap_null, C_is_csc,
-                GxB_HYPERSPARSE, A_hyper_switch, 0) ;
+                ctype, avdim, avlen, GB_ph_null, C_is_csc,
+                GxB_HYPERSPARSE, A_hyper_switch, 0,
+                Cp_is_32, Cj_is_32, Ci_is_32) ;
             ASSERT (info == GrB_SUCCESS) ;
 
             // if in_place, the prior A->p and A->h can now be freed
             if (in_place)
             { 
-                if (!A->p_shallow) GB_FREE (&A->p, A->p_size) ;
-                if (!A->h_shallow) GB_FREE (&A->h, A->h_size) ;
+                if (!A->p_shallow) GB_FREE_MEMORY (&A->p, A->p_size) ;
+                if (!A->h_shallow) GB_FREE_MEMORY (&A->h, A->h_size) ;
             }
 
             GB_void *S_input = NULL ;
@@ -753,14 +810,14 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             if (!recycle_Ai)
             { 
                 // allocate jwork of size anz
-                jwork = GB_MALLOC (anz, int64_t, &jwork_size) ;
+                jwork = GB_MALLOC_MEMORY (anz, aisize, &jwork_size) ;
                 ok = ok && (jwork != NULL) ;
             }
 
             if (op != NULL && !C_iso)
             { 
-                Swork = (GB_void *) GB_XALLOC (false, C_iso, anz,   // x:OK
-                    csize, &Swork_size) ;
+                Swork = (GB_void *) GB_XALLOC_MEMORY (false, C_iso, anz, csize,
+                    &Swork_size) ;
                 ok = ok && (Swork != NULL) ;
             }
 
@@ -789,7 +846,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             { 
                 // copy A->i into jwork, making a deep copy.  jwork is freed by
                 // GB_builder.  A->i is not modified, even if out of memory.
-                GB_memcpy (jwork, A->i, anz * sizeof (int64_t), nthreads_max) ;
+                GB_memcpy (jwork, A->i, anz * aisize, nthreads_max) ;
             }
 
             // numerical values: apply the op, typecast, or make shallow copy
@@ -831,7 +888,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             //------------------------------------------------------------------
 
             // internally, jwork is freed and then T->x is allocated, so the
-            // total memory usage is anz * max (csize, sizeof(int64_t)).  T is
+            // total memory usage is anz * max (csize, sizeof(aisize)).  T is
             // always hypersparse.  Either T, Swork, and S_input are all iso,
             // or all non-iso, depending on C_iso.
 
@@ -858,7 +915,9 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
                 NULL,       // no dup operator needed (input has no duplicates)
                 stype,      // type of S_input or Swork
                 false,      // no burble (already burbled above)
-                Werk
+                Werk,
+                Aj_is_32, Ai_is_32, // integer sizes of iwork and jwork
+                Cp_is_32, Cj_is_32, Ci_is_32  // integer sizes for T 
             )) ;
 
             // GB_builder always frees jwork, and either frees iwork or
@@ -886,6 +945,17 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
         }
     }
 
+    //==========================================================================
+    // conform the integers
+    //==========================================================================
+
+    // In case T was created using the integers of A, it must be converted to
+    // the requested integers of C.  This does nothing if T was already created
+    // in that form.
+    GB_determine_pji_is_32 (&Cp_is_32, &Cj_is_32, &Ci_is_32,
+        GB_sparsity (T), anz, avdim, avlen, Werk) ;
+    GB_OK (GB_convert_int (T, Cp_is_32, Cj_is_32, Ci_is_32, true)) ;
+
     //==========================================================================
     // free workspace, apply positional op, and transplant/conform T into C
     //==========================================================================
@@ -925,7 +995,6 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             // If C was constructed as iso; it needs to be expanded first,
             // but do not initialize the values.  These are computed by
             // GB_apply_op below.
-            // set C->iso = false    OK: no need to burble
             GB_OK (GB_convert_any_to_non_iso (C, false)) ;
         }
 
@@ -962,12 +1031,12 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             if (GB_IS_BITMAP (C))
             { 
                 // calloc the space so the new C->x has no uninitialized space
-                Cx_new = GB_CALLOC (anz_held*csize, GB_void, &Cx_size) ; // x:OK
+                Cx_new = GB_CALLOC_MEMORY (anz_held, csize, &Cx_size) ;
             }
             else
             { 
                 // malloc is fine; all C->x will be written
-                Cx_new = GB_MALLOC (anz_held*csize, GB_void, &Cx_size) ; // x:OK
+                Cx_new = GB_MALLOC_MEMORY (anz_held, csize, &Cx_size) ;
             }
             if (Cx_new == NULL)
             { 
@@ -979,7 +1048,7 @@ GrB_Info GB_transpose           // C=A', C=(ctype)A' or C=op(A')
             GB_OK (GB_apply_op (Cx_new, ctype, GB_NON_ISO, op,
                 scalar, false, flipij, C, Werk)) ;
             // transplant Cx_new as C->x and finalize the type of C
-            GB_FREE (&(C->x), C->x_size) ;
+            GB_FREE_MEMORY (&(C->x), C->x_size) ;
             C->x = Cx_new ;
             C->x_size = Cx_size ;
             C->type = ctype ;
